==> zio-aws-securitylake_3-5.19.31.4-sources.jar: zio/aws/securitylake/model/package.scala <==
package zio.aws.securitylake
import zio.aws.securitylake.model.primitives.SafeString
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.securitylake.model.primitives.UpdateDatalakeExceptionsExpiryRequestExceptionMessageExpiryLong.Type
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object AwsAccountId extends Subtype[String]
    type AwsAccountId = zio.aws.securitylake.model.primitives.AwsAccountId.Type
    object CreateSubscriberRequestSubscriberNameString extends Subtype[String]
    type CreateSubscriberRequestSubscriberNameString =
      zio.aws.securitylake.model.primitives.CreateSubscriberRequestSubscriberNameString.Type
    object CreateSubscriptionNotificationConfigurationRequestSubscriptionEndpointString
        extends Subtype[String]
    type CreateSubscriptionNotificationConfigurationRequestSubscriptionEndpointString =
      zio.aws.securitylake.model.primitives.CreateSubscriptionNotificationConfigurationRequestSubscriptionEndpointString.Type
    object CustomSourceType extends Subtype[String]
    type CustomSourceType =
      zio.aws.securitylake.model.primitives.CustomSourceType.Type
    object DescriptionString extends Subtype[String]
    type DescriptionString =
      zio.aws.securitylake.model.primitives.DescriptionString.Type
    type Integer = Int
    object RetentionSettingRetentionPeriodInteger extends Subtype[Int]
    type RetentionSettingRetentionPeriodInteger =
      zio.aws.securitylake.model.primitives.RetentionSettingRetentionPeriodInteger.Type
    object RoleArn extends Subtype[String]
    type RoleArn = zio.aws.securitylake.model.primitives.RoleArn.Type
    object S3BucketArn extends Subtype[String]
    type S3BucketArn = zio.aws.securitylake.model.primitives.S3BucketArn.Type
    object SafeString extends Subtype[String]
    type SafeString = zio.aws.securitylake.model.primitives.SafeString.Type
    object SnsTopicArn extends Subtype[String]
    type SnsTopicArn = zio.aws.securitylake.model.primitives.SnsTopicArn.Type
    object SyntheticTimestamp_date_time extends Subtype[Instant]
    type SyntheticTimestamp_date_time =
      zio.aws.securitylake.model.primitives.SyntheticTimestamp_date_time.Type
    object UUID extends Subtype[String]
    type UUID = zio.aws.securitylake.model.primitives.UUID.Type
    object UpdateDatalakeExceptionsExpiryRequestExceptionMessageExpiryLong
        extends Subtype[Long]
    type UpdateDatalakeExceptionsExpiryRequestExceptionMessageExpiryLong =
      zio.aws.securitylake.model.primitives.UpdateDatalakeExceptionsExpiryRequestExceptionMessageExpiryLong.Type
    object UpdateSubscriberRequestSubscriberNameString extends Subtype[String]
    type UpdateSubscriberRequestSubscriberNameString =
      zio.aws.securitylake.model.primitives.UpdateSubscriberRequestSubscriberNameString.Type
    object UpdateSubscriptionNotificationConfigurationRequestSubscriptionEndpointString
        extends Subtype[String]
    type UpdateSubscriptionNotificationConfigurationRequestSubscriptionEndpointString =
      zio.aws.securitylake.model.primitives.UpdateSubscriptionNotificationConfigurationRequestSubscriptionEndpointString.Type
  }
  type AccessTypeList = List[zio.aws.securitylake.model.AccessType]
  type AccountList = List[String]
  type AccountSourcesList = List[zio.aws.securitylake.model.AccountSources]
  type AllDimensionsMap = Map[String, Map[String, Iterable[String]]]
  type AutoEnableNewRegionConfigurationList =
    List[zio.aws.securitylake.model.AutoEnableNewRegionConfiguration]
  type AwsSourceTypeList = List[zio.aws.securitylake.model.AwsLogSourceType]
  type DimensionSet = List[zio.aws.securitylake.model.Dimension]
  type FailuresResponseList = List[zio.aws.securitylake.model.FailuresResponse]
  type Failureslist = List[zio.aws.securitylake.model.Failures]
  type InputSet = List[SafeString]
  type LakeConfigurationRequestMap = Map[
    zio.aws.securitylake.model.Region,
    zio.aws.securitylake.model.LakeConfigurationRequest
  ]
  type LakeConfigurationResponseMap = Map[
    zio.aws.securitylake.model.Region,
    zio.aws.securitylake.model.LakeConfigurationResponse
  ]
  type LogsStatusList = List[zio.aws.securitylake.model.LogsStatus]
  type RegionSet = List[zio.aws.securitylake.model.Region]
  type RegionSourceTypesAccountsList =
    List[Map[String, Map[String, Iterable[String]]]]
  type RetentionSettingList = List[zio.aws.securitylake.model.RetentionSetting]
  type SourceTypeList = List[zio.aws.securitylake.model.SourceType]
  type SubscriberList = List[zio.aws.securitylake.model.SubscriberResource]
  type TagsMap = Map[String, String]
  type TwoDimensionsMap = Map[String, Iterable[String]]
  type ValueSet = List[String]
}

==> zio-aws-securitylake_3-5.20.32.1-sources.jar: zio/aws/securitylake/model/package.scala <==
package zio.aws.securitylake
import zio.aws.securitylake.model.primitives.SafeString
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.securitylake.model.primitives.UpdateDatalakeExceptionsExpiryRequestExceptionMessageExpiryLong.Type
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object AwsAccountId extends Subtype[String]
    type AwsAccountId = zio.aws.securitylake.model.primitives.AwsAccountId.Type
    object CreateSubscriberRequestSubscriberNameString extends Subtype[String]
    type CreateSubscriberRequestSubscriberNameString =
      zio.aws.securitylake.model.primitives.CreateSubscriberRequestSubscriberNameString.Type
    object CreateSubscriptionNotificationConfigurationRequestSubscriptionEndpointString
        extends Subtype[String]
    type CreateSubscriptionNotificationConfigurationRequestSubscriptionEndpointString =
      zio.aws.securitylake.model.primitives.CreateSubscriptionNotificationConfigurationRequestSubscriptionEndpointString.Type
    object CustomSourceType extends Subtype[String]
    type CustomSourceType =
      zio.aws.securitylake.model.primitives.CustomSourceType.Type
    object DescriptionString extends Subtype[String]
    type DescriptionString =
      zio.aws.securitylake.model.primitives.DescriptionString.Type
    type Integer = Int
    object ResourceShareArn extends Subtype[String]
    type ResourceShareArn =
      zio.aws.securitylake.model.primitives.ResourceShareArn.Type
    object ResourceShareName extends Subtype[String]
    type ResourceShareName =
      zio.aws.securitylake.model.primitives.ResourceShareName.Type
    object RetentionSettingRetentionPeriodInteger extends Subtype[Int]
    type RetentionSettingRetentionPeriodInteger =
      zio.aws.securitylake.model.primitives.RetentionSettingRetentionPeriodInteger.Type
    object RoleArn extends Subtype[String]
    type RoleArn = zio.aws.securitylake.model.primitives.RoleArn.Type
    object S3BucketArn extends Subtype[String]
    type S3BucketArn = zio.aws.securitylake.model.primitives.S3BucketArn.Type
    object SafeString extends Subtype[String]
    type SafeString = zio.aws.securitylake.model.primitives.SafeString.Type
    object SnsTopicArn extends Subtype[String]
    type SnsTopicArn = zio.aws.securitylake.model.primitives.SnsTopicArn.Type
    object SyntheticTimestamp_date_time extends Subtype[Instant]
    type SyntheticTimestamp_date_time =
      zio.aws.securitylake.model.primitives.SyntheticTimestamp_date_time.Type
    object UUID extends Subtype[String]
    type UUID = zio.aws.securitylake.model.primitives.UUID.Type
    object UpdateDatalakeExceptionsExpiryRequestExceptionMessageExpiryLong
        extends Subtype[Long]
    type UpdateDatalakeExceptionsExpiryRequestExceptionMessageExpiryLong =
      zio.aws.securitylake.model.primitives.UpdateDatalakeExceptionsExpiryRequestExceptionMessageExpiryLong.Type
    object UpdateSubscriberRequestSubscriberNameString extends Subtype[String]
    type UpdateSubscriberRequestSubscriberNameString =
      zio.aws.securitylake.model.primitives.UpdateSubscriberRequestSubscriberNameString.Type
    object UpdateSubscriptionNotificationConfigurationRequestSubscriptionEndpointString
        extends Subtype[String]
    type UpdateSubscriptionNotificationConfigurationRequestSubscriptionEndpointString =
      zio.aws.securitylake.model.primitives.UpdateSubscriptionNotificationConfigurationRequestSubscriptionEndpointString.Type
  }
  type AccessTypeList = List[zio.aws.securitylake.model.AccessType]
  type AccountList = List[String]
  type AccountSourcesList = List[zio.aws.securitylake.model.AccountSources]
  type AllDimensionsMap = Map[String, Map[String, Iterable[String]]]
  type AutoEnableNewRegionConfigurationList =
    List[zio.aws.securitylake.model.AutoEnableNewRegionConfiguration]
  type AwsSourceTypeList = List[zio.aws.securitylake.model.AwsLogSourceType]
  type DimensionSet = List[zio.aws.securitylake.model.Dimension]
  type FailuresResponseList = List[zio.aws.securitylake.model.FailuresResponse]
  type Failureslist = List[zio.aws.securitylake.model.Failures]
  type InputSet = List[SafeString]
  type LakeConfigurationRequestMap = Map[
    zio.aws.securitylake.model.Region,
    zio.aws.securitylake.model.LakeConfigurationRequest
  ]
  type LakeConfigurationResponseMap = Map[
    zio.aws.securitylake.model.Region,
    zio.aws.securitylake.model.LakeConfigurationResponse
  ]
  type LogsStatusList = List[zio.aws.securitylake.model.LogsStatus]
  type RegionSet = List[zio.aws.securitylake.model.Region]
  type RegionSourceTypesAccountsList =
    List[Map[String, Map[String, Iterable[String]]]]
  type RetentionSettingList = List[zio.aws.securitylake.model.RetentionSetting]
  type SourceTypeList = List[zio.aws.securitylake.model.SourceType]
  type SubscriberList = List[zio.aws.securitylake.model.SubscriberResource]
  type TagsMap = Map[String, String]
  type TwoDimensionsMap = Map[String, Iterable[String]]
  type ValueSet = List[String]
}
